# Logpack

> 便捷、灵敏、持续开发。

## 目录

1. 介绍
2. 安装
3. 用法
4. 展望
5. 开原许可

## 介绍

便捷、灵敏、持续开发。

## 安装

```shell
pip install logpack
```

## 用法

`example.py`里面有**渐进式的教学**。读源码是个好习惯，这个项目也不复杂。

## 展望

参见`example.py`。

## 开原许可

遵循AGPL v3.0开源协议。
